# bhoelHelper module #

Some helper modules used in my other modules.

# Installation #

pip install bhoelHelper

## Availability

The latest version should be available at my
[GitLab](https://gitlab.com/berhoel/python/bhoelHelper.git) repository, the
package is avaliable at [pypi](https://pypi.org/project/bhoelHelper/) via
`pip install bhoelHelper`.
